#[repr(u8)]pub enum Fof {
FOF_0 = 0,
FOF_1 = 1,
}Variants
FOF_0 = 0
No result FIFO overflow has occurred since the last time the flag was cleared.
FOF_1 = 1
At least one result FIFO overflow has occurred since the last time the flag was cleared.
Implementations