#[repr(u8)]pub enum Pwren {
PWREN_0 = 0,
PWREN_1 = 1,
}Variants
PWREN_0 = 0
ADC analog circuits are only enabled while conversions are active. Performance is affected due to analog startup delays.
PWREN_1 = 1
ADC analog circuits are pre-enabled and ready to execute conversions without startup delays (at the cost of higher DC current consumption). When PWREN is set, the power up delay is enforced such that any detected trigger does not begin ADC operation until the power up delay time has passed.
Implementations