nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Tprictrl

Enum Tprictrl 

#[repr(u8)]
pub enum Tprictrl { TPRICTRL_0 = 0, TPRICTRL_1 = 1, }

Variants



TPRICTRL_0 = 0

If a higher priority trigger is detected during command processing, the current conversion is aborted and the new command specified by the trigger is started.



TPRICTRL_1 = 1

If a higher priority trigger is received during command processing, the current conversion is completed (including averaging iterations and compare function if enabled) and stored to the RESFIFO before the higher priority trigger/command is initiated.

Implementations

Source

impl Tprictrl

pub const fn from_bits(val: u8) -> Tprictrl

pub const fn to_bits(self) -> u8