#[repr(u8)]pub enum Tprictrl {
TPRICTRL_0 = 0,
TPRICTRL_1 = 1,
}Variants
TPRICTRL_0 = 0
If a higher priority trigger is detected during command processing, the current conversion is aborted and the new command specified by the trigger is started.
TPRICTRL_1 = 1
If a higher priority trigger is received during command processing, the current conversion is completed (including averaging iterations and compare function if enabled) and stored to the RESFIFO before the higher priority trigger/command is initiated.
Implementations